@@ -29,7 +29,7 @@ class FakeScalingPolicy(object):
 class FakeLaunchConfiguration(object):
     def __init__(self, name, image_id, key_name, security_groups, user_data,
                  instance_type, instance_monitoring, instance_profile_name,
-                 spot_price, ebs_optimized):
+                 spot_price, ebs_optimized, associate_public_ip_address):
         self.name = name
         self.image_id = image_id
         self.key_name = key_name
@@ -40,6 +40,7 @@ class FakeLaunchConfiguration(object):
         self.instance_profile_name = instance_profile_name
         self.spot_price = spot_price
         self.ebs_optimized = ebs_optimized
+        self.associate_public_ip_address = associate_public_ip_address
 
     @property
     def instance_monitoring_enabled(self):
@@ -129,7 +130,7 @@ class AutoScalingBackend(BaseBackend):
     def create_launch_configuration(self, name, image_id, key_name,
                                     security_groups, user_data, instance_type,
                                     instance_monitoring, instance_profile_name,
-                                    spot_price, ebs_optimized):
+                                    spot_price, ebs_optimized, associate_public_ip_address):
         launch_configuration = FakeLaunchConfiguration(
             name=name,
             image_id=image_id,
@@ -141,6 +142,7 @@ class AutoScalingBackend(BaseBackend):
             instance_profile_name=instance_profile_name,
             spot_price=spot_price,
             ebs_optimized=ebs_optimized,
+            associate_public_ip_address=associate_public_ip_address,
         )
         self.launch_configurations[name] = launch_configuration
         return launch_configuration
