@@ -19,6 +19,7 @@ from .utils import (
     random_eip_association_id,
     random_eip_allocation_id,
     random_ip,
+    random_key_pair,
 )
 
 
@@ -161,6 +162,33 @@ class InstanceBackend(object):
             return [reservation for reservation in self.reservations.values()]
 
 
+class KeyPairBackend(object):
+
+    def __init__(self):
+        self.keypairs = defaultdict(dict)
+        super(KeyPairBackend, self).__init__()
+
+    def create_key_pair(self, name):
+        if name in self.keypairs:
+            raise InvalidIdError(name)
+        self.keypairs[name] = keypair = random_key_pair()
+        keypair['name'] = name
+        return keypair
+
+    def delete_key_pair(self, name):
+        if name in self.keypairs:
+            self.keypairs.pop(name)
+        return True
+
+    def describe_key_pairs(self, filter_names=None):
+        results = []
+        for name, keypair in self.keypairs.iteritems():
+            if not filter_names or name in filter_names:
+                keypair['name'] = name
+                results.append(keypair)
+        return results
+
+
 class TagBackend(object):
 
     def __init__(self):
@@ -219,14 +247,14 @@ class AmiBackend(object):
         self.amis[ami_id] = ami
         return ami
 
-    def describe_images(self, ami_ids=None):
-        if ami_ids:
-            images = [image for image in self.amis.values() if image.id in ami_ids]
-            for missing_ami in set(ami_ids) - set(ami.id for ami in images):
-                raise InvalidIdError(missing_ami)
-        else:
-            images = self.amis.values()
-        return images
+    def describe_images(self, ami_ids=()):
+        images = []
+        for ami_id in ami_ids:
+            if ami_id in self.amis:
+                images.append(self.amis[ami_id])
+            else:
+                raise InvalidIdError(ami_id)
+        return images or self.amis.values()
 
     def deregister_image(self, ami_id):
         if ami_id in self.amis:
@@ -675,7 +703,8 @@ class ElasticAddressBackend(object):
 
 class EC2Backend(BaseBackend, InstanceBackend, TagBackend, AmiBackend,
                  RegionsAndZonesBackend, SecurityGroupBackend, EBSBackend,
-                 VPCBackend, SubnetBackend, SpotRequestBackend, ElasticAddressBackend):
+                 VPCBackend, SubnetBackend, SpotRequestBackend, ElasticAddressBackend,
+                 KeyPairBackend):
     pass
 
 
