@@ -6,5 +6,5 @@ url_bases = [
 
 url_paths = {
     '{0}/$': S3ResponseInstance.bucket_response,
-    '{0}/(?P<key_name>[a-zA-Z0-9\-_.]+)': S3ResponseInstance.key_response,
+    '{0}/(?P<key_name>.+)': S3ResponseInstance.key_response,
 }
